[gnus git] branch master updated: m0-11-206-ge111930 =1= dgnushack.el (define-obsolete-function-alias): Redefine for XEmacs

Katsumi <[email protected]> Tue, 07 Apr 2015 01:08:03 +0200
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  e111930368a2ec2749860e85e8e115c463ff138f (commit)
      from  fc3453fd537ebe34dcc9a6bcf994edea56ea14af (commit)


- Log -----------------------------------------------------------------
commit e111930368a2ec2749860e85e8e115c463ff138f
Author: Katsumi Yamaoka <[email protected]>
Date:   Mon Apr 6 23:07:56 2015 +0000

    dgnushack.el (define-obsolete-function-alias): Redefine for XEmacs

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 4c2359b..ef12266 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,9 @@
+2015-04-06  Katsumi Yamaoka  <[email protected]>
+
+	* dgnushack.el (define-obsolete-function-alias): Add a compiler-marco
+	and a runtime function for it, of which the XEmacs version takes only
+	two arguments.
+
 2015-04-06  Paul Eggert  <[email protected]>
 
 	Use American spelling for 'normalize'
diff --git a/lisp/dgnushack.el b/lisp/dgnushack.el
index d65d24b..99b4f5b 100644
--- a/lisp/dgnushack.el
+++ b/lisp/dgnushack.el
@@ -568,17 +568,26 @@ but which should be robust in the unexpected case that an error is signaled."
 	   (progn ,@body)
 	 (error (message "Error: %S" ,err) nil)))))
 
 ;; XEmacs's `define-obsolete-variable-alias' takes only two arguments:
 ;; (define-obsolete-variable-alias OLDVAR NEWVAR)
 (condition-case nil
-    (progn
-      (defvar dgnushack-obsolete-name nil)
-      (defvar dgnushack-current-name nil)
-      (unwind-protect
+    (define-obsolete-function-alias
+      'dgnushack-obsolete-name 'dgnushack-current-name "0")
+  (wrong-number-of-arguments
+   (defadvice define-obsolete-function-alias (around ignore-rest-args
+						     (oldfun newfun &rest args)
+						     activate)
+     "Ignore arguments other than the 1st and the 2nd ones."
+     ad-do-it)
+   (put 'define-obsolete-function-alias 'byte-optimizer
+	(lambda (form)
+	  (setcdr (nthcdr 2 form) nil)
+	  form))))
+(condition-case nil
     (define-obsolete-variable-alias
       'dgnushack-obsolete-name 'dgnushack-current-name "0")
-	(makunbound 'dgnushack-obsolete-name)
-	(makunbound 'dgnushack-current-name)))
   (wrong-number-of-arguments
    (defadvice define-obsolete-variable-alias (around ignore-rest-args
 						     (oldvar newvar &rest args)

-----------------------------------------------------------------------
@@ -568,17 +568,26 @@ but which should be robust in the unexpected case that an error is signaled."
 	 (error (message "Error: %S" ,err) nil)))))
 
-;; XEmacs's `define-obsolete-variable-alias' takes only two arguments:
+;; `define-obsolete-function-alias' and `define-obsolete-variable-alias'
+;; take only two arguments in XEmacs:
+;; (define-obsolete-function-alias OLDFUN NEWFUN)
 ;; (define-obsolete-variable-alias OLDVAR NEWVAR)
 (condition-case nil
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/ChangeLog    |    6 ++++++
 lisp/dgnushack.el |   27 ++++++++++++++++++---------
 2 files changed, 24 insertions(+), 9 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
-- 
Gnus Project